@@ -1,10 +1,12 @@
 #!/usr/bin/perl -w
 use strict;
+use Data::Dumper;
 use FindBin;
 use File::Spec::Functions;
 use Storable;
-use YAML;
 use lib "$FindBin::Bin/../lib";
+$Data::Dumper::Sortkeys = 1;
+$Data::Dumper::Indent = 1;
 
 my $arg = shift || die "Pass a string to search for";
 
@@ -13,7 +15,7 @@ my $cpants = retrieve (catfile "$FindBin::Bin/../", "cpants.store")
 
 foreach my $dist (sort keys %$cpants) {
   next unless $dist =~ /$arg/;
-  print Dump({ $dist => $cpants->{$dist}});
+  print Dumper({$dist => $cpants->{$dist}});
   print "\n";
 }
 
