@@ -1,39 +1,16 @@
 package Module::CPANTS::Generator::Files;
 use strict;
-use Carp;
-use Cwd;
 use File::Spec::Functions;
-use Storable;
+use Module::CPANTS::Generator;
+use base 'Module::CPANTS::Generator';
+
 use vars qw($VERSION);
-$VERSION = "0.003";
-
-sub new {
-  my $class = shift;
-  my $self = {};
-  bless $self, $class;
-}
-
-sub directory {
-  my($self, $dir) = @_;
-  if (defined $dir) {
-    $self->{DIR} = $dir;
-  } else {
-    return $self->{DIR};
-  }
-}
+$VERSION = "0.004";
 
 sub generate {
   my $self = shift;
 
-  my $cpants = {};
-  eval {
-    $cpants = retrieve("cpants.store");
-  };
-  # warn $@ if $@;
-  my $origdir = cwd;
-
-  my $dir = $self->directory || croak("No directory specified");
-  chdir $dir || croak("Could not chdir into $dir");
+  my $cpants = $self->grab_cpants;
 
   foreach my $dist (sort grep { -d } <*>) {
     my @files;
@@ -46,8 +23,7 @@ sub generate {
     }
   }
 
-  chdir $origdir;
-  store($cpants, "cpants.store");
+  $self->save_cpants($cpants);
 }
 
 1;
